@@ -1,6 +1,7 @@
 
-#Function to calculate weighted means for each cluster
-#x is the data matrix, cl is the cluster assignment vector,  w is the weight vector
+# Function to get the weighted centers for the clusters
+# x is the data matrix, cl is the cluster assignment vector,  w is the weight vector
+
 wmean = function (x, cl, w = rep(1,length(x))) {
 
   x = as.data.frame(x)
@@ -16,15 +17,17 @@ wmean = function (x, cl, w = rep(1,length(x))) {
     stop("The length of cluster assignments should be the same as the number of observations. ")
 
   }
-  # get the number of clusters
-  ncl=max(cl)
+  
+  #get the number of clusters
+  cl1 = as.numeric(factor(cl))
 
   res = NULL
-  for(i in 1:ncl)
-    res = cbind(res,apply(x[cl==i,,drop=F],2,weighted.mean,w=w[cl==i]))
+  
+  for(i in 1:max(cl1))
+    res = cbind(res,apply(x[cl1==i,,drop=F],2,weighted.mean,w=w[cl1==i]))
 
 
-  colnames(res) = paste("Cluster Center.",1:ncl,sep = "")
+  colnames(res) = paste("Cluster Center.",1:max(cl1),sep = "")
 
   res
 }
